==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/TransitGatewayMulticastRegisteredGroupMembers.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TransitGatewayMulticastRegisteredGroupMembers(
    transitGatewayMulticastDomainId: Option[String] = None,
    registeredNetworkInterfaceIds: Option[Iterable[String]] = None,
    groupIpAddress: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers = {
    import TransitGatewayMulticastRegisteredGroupMembers.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
      .builder()
      .optionallyWith(
        transitGatewayMulticastDomainId.map(value => value: java.lang.String)
      )(_.transitGatewayMulticastDomainId)
      .optionallyWith(
        registeredNetworkInterfaceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.registeredNetworkInterfaceIds)
      .optionallyWith(groupIpAddress.map(value => value: java.lang.String))(
        _.groupIpAddress
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly =
    zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
      .wrap(buildAwsValue())
}
object TransitGatewayMulticastRegisteredGroupMembers {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers =
      zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers(
        transitGatewayMulticastDomainId.map(value => value),
        registeredNetworkInterfaceIds.map(value => value),
        groupIpAddress.map(value => value)
      )
    def transitGatewayMulticastDomainId: Option[String]
    def registeredNetworkInterfaceIds: Option[List[String]]
    def groupIpAddress: Option[String]
    def getTransitGatewayMulticastDomainId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "transitGatewayMulticastDomainId",
        transitGatewayMulticastDomainId
      )
    def getRegisteredNetworkInterfaceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField(
        "registeredNetworkInterfaceIds",
        registeredNetworkInterfaceIds
      )
    def getGroupIpAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("groupIpAddress", groupIpAddress)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ) extends zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly {
    override val transitGatewayMulticastDomainId: Option[String] = scala
      .Option(impl.transitGatewayMulticastDomainId())
      .map(value => value: String)
    override val registeredNetworkInterfaceIds: Option[List[String]] = scala
      .Option(impl.registeredNetworkInterfaceIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val groupIpAddress: Option[String] =
      scala.Option(impl.groupIpAddress()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ): zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.194.1-sources.jar: zio/aws/ec2/model/TransitGatewayMulticastRegisteredGroupMembers.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TransitGatewayMulticastRegisteredGroupMembers(
    transitGatewayMulticastDomainId: Optional[String] = Optional.Absent,
    registeredNetworkInterfaceIds: Optional[Iterable[String]] = Optional.Absent,
    groupIpAddress: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers = {
    import TransitGatewayMulticastRegisteredGroupMembers.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
      .builder()
      .optionallyWith(
        transitGatewayMulticastDomainId.map(value => value: java.lang.String)
      )(_.transitGatewayMulticastDomainId)
      .optionallyWith(
        registeredNetworkInterfaceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.registeredNetworkInterfaceIds)
      .optionallyWith(groupIpAddress.map(value => value: java.lang.String))(
        _.groupIpAddress
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly =
    zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
      .wrap(buildAwsValue())
}
object TransitGatewayMulticastRegisteredGroupMembers {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers =
      zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers(
        transitGatewayMulticastDomainId.map(value => value),
        registeredNetworkInterfaceIds.map(value => value),
        groupIpAddress.map(value => value)
      )
    def transitGatewayMulticastDomainId: Optional[String]
    def registeredNetworkInterfaceIds: Optional[List[String]]
    def groupIpAddress: Optional[String]
    def getTransitGatewayMulticastDomainId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "transitGatewayMulticastDomainId",
        transitGatewayMulticastDomainId
      )
    def getRegisteredNetworkInterfaceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField(
        "registeredNetworkInterfaceIds",
        registeredNetworkInterfaceIds
      )
    def getGroupIpAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("groupIpAddress", groupIpAddress)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ) extends zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly {
    override val transitGatewayMulticastDomainId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayMulticastDomainId())
        .map(value => value: String)
    override val registeredNetworkInterfaceIds: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.registeredNetworkInterfaceIds())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
    override val groupIpAddress: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.groupIpAddress())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayMulticastRegisteredGroupMembers
  ): zio.aws.ec2.model.TransitGatewayMulticastRegisteredGroupMembers.ReadOnly =
    new Wrapper(impl)
}
